# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["OhlcGetParams"]


class OhlcGetParams(TypedDict, total=False):
    days: Required[Literal["1", "7", "14", "30", "90", "180", "365", "max"]]
    """data up to number of days ago"""

    vs_currency: Required[str]
    """
    target currency of price data \\**refers to
    [`/simple/supported_vs_currencies`](/reference/simple-supported-currencies).
    """

    interval: Literal["daily", "hourly"]
    """data interval, leave empty for auto granularity"""

    precision: Literal[
        "full", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "17", "18"
    ]
    """decimal place for currency price value"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["ListGetParams"]


class ListGetParams(TypedDict, total=False):
    include_platform: bool
    """include platform and token's contract addresses, default: false"""

    status: Literal["active", "inactive"]
    """filter by status of coins, default: active"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["CategoryGetPoolsParams"]


class CategoryGetPoolsParams(TypedDict, total=False):
    include: str
    """
    attributes to include, comma-separated if more than one to include Available
    values: `base_token`, `quote_token`, `dex`, `network`. Example: `base_token` or
    `base_token,dex`
    """

    page: int
    """page through results Default value: `1`"""

    sort: Literal[
        "m5_trending",
        "h1_trending",
        "h6_trending",
        "h24_trending",
        "h24_tx_count_desc",
        "h24_volume_usd_desc",
        "pool_created_at_desc",
        "h24_price_change_percentage_desc",
    ]
    """sort the pools by field Default value: `pool_created_at_desc`"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.key_get_response import KeyGetResponse

__all__ = ["KeyResource", "AsyncKeyResource"]


class KeyResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> KeyResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return KeyResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> KeyResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return KeyResourceWithStreamingResponse(self)

    def get(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KeyGetResponse:
        """
        This endpoint allows you to **monitor your account's API usage, including rate
        limits, monthly total credits, remaining credits, and more**
        """
        return self._get(
            "/key",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KeyGetResponse,
        )


class AsyncKeyResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncKeyResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncKeyResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncKeyResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncKeyResourceWithStreamingResponse(self)

    async def get(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KeyGetResponse:
        """
        This endpoint allows you to **monitor your account's API usage, including rate
        limits, monthly total credits, remaining credits, and more**
        """
        return await self._get(
            "/key",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KeyGetResponse,
        )


class KeyResourceWithRawResponse:
    def __init__(self, key: KeyResource) -> None:
        self._key = key

        self.get = to_raw_response_wrapper(
            key.get,
        )


class AsyncKeyResourceWithRawResponse:
    def __init__(self, key: AsyncKeyResource) -> None:
        self._key = key

        self.get = async_to_raw_response_wrapper(
            key.get,
        )


class KeyResourceWithStreamingResponse:
    def __init__(self, key: KeyResource) -> None:
        self._key = key

        self.get = to_streamed_response_wrapper(
            key.get,
        )


class AsyncKeyResourceWithStreamingResponse:
    def __init__(self, key: AsyncKeyResource) -> None:
        self._key = key

        self.get = async_to_streamed_response_wrapper(
            key.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ...._models import BaseModel

__all__ = [
    "InfoRecentlyUpdatedGetResponse",
    "Data",
    "DataAttributes",
    "DataRelationships",
    "DataRelationshipsNetwork",
    "DataRelationshipsNetworkData",
]


class DataAttributes(BaseModel):
    address: Optional[str] = None

    coingecko_coin_id: Optional[str] = None

    description: Optional[str] = None

    gt_score: Optional[float] = None

    image_url: Optional[str] = None

    metadata_updated_at: Optional[str] = None

    name: Optional[str] = None

    symbol: Optional[str] = None

    websites: Optional[List[str]] = None


class DataRelationshipsNetworkData(BaseModel):
    id: Optional[str] = None

    type: Optional[str] = None


class DataRelationshipsNetwork(BaseModel):
    data: Optional[DataRelationshipsNetworkData] = None


class DataRelationships(BaseModel):
    network: Optional[DataRelationshipsNetwork] = None


class Data(BaseModel):
    id: Optional[str] = None

    attributes: Optional[DataAttributes] = None

    relationships: Optional[DataRelationships] = None

    type: Optional[str] = None


class InfoRecentlyUpdatedGetResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .pool_get_params import PoolGetParams as PoolGetParams
from .trade_get_params import TradeGetParams as TradeGetParams
from .info_get_response import InfoGetResponse as InfoGetResponse
from .pool_get_response import PoolGetResponse as PoolGetResponse
from .trade_get_response import TradeGetResponse as TradeGetResponse
from .top_holder_get_params import TopHolderGetParams as TopHolderGetParams
from .top_holder_get_response import TopHolderGetResponse as TopHolderGetResponse
from .holders_chart_get_params import HoldersChartGetParams as HoldersChartGetParams
from .holders_chart_get_response import HoldersChartGetResponse as HoldersChartGetResponse
from .multi_get_addresses_params import MultiGetAddressesParams as MultiGetAddressesParams
from .ohlcv_get_timeframe_params import OhlcvGetTimeframeParams as OhlcvGetTimeframeParams
from .multi_get_addresses_response import MultiGetAddressesResponse as MultiGetAddressesResponse
from .ohlcv_get_timeframe_response import OhlcvGetTimeframeResponse as OhlcvGetTimeframeResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ....._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ....._utils import maybe_transform, async_maybe_transform
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....._base_client import make_request_options
from .....types.onchain.networks.tokens import holders_chart_get_params
from .....types.onchain.networks.tokens.holders_chart_get_response import HoldersChartGetResponse

__all__ = ["HoldersChartResource", "AsyncHoldersChartResource"]


class HoldersChartResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> HoldersChartResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return HoldersChartResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> HoldersChartResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return HoldersChartResourceWithStreamingResponse(self)

    def get(
        self,
        token_address: str,
        *,
        network: str,
        days: Literal["7", "30", "max"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> HoldersChartGetResponse:
        """
        This endpoint allows you to **get the historical token holders chart based on
        the provided token contract address on a network**

        Args:
          days: number of days to return the historical token holders chart Default value: 7

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not network:
            raise ValueError(f"Expected a non-empty value for `network` but received {network!r}")
        if not token_address:
            raise ValueError(f"Expected a non-empty value for `token_address` but received {token_address!r}")
        return self._get(
            f"/onchain/networks/{network}/tokens/{token_address}/holders_chart",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"days": days}, holders_chart_get_params.HoldersChartGetParams),
            ),
            cast_to=HoldersChartGetResponse,
        )


class AsyncHoldersChartResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncHoldersChartResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncHoldersChartResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncHoldersChartResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncHoldersChartResourceWithStreamingResponse(self)

    async def get(
        self,
        token_address: str,
        *,
        network: str,
        days: Literal["7", "30", "max"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> HoldersChartGetResponse:
        """
        This endpoint allows you to **get the historical token holders chart based on
        the provided token contract address on a network**

        Args:
          days: number of days to return the historical token holders chart Default value: 7

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not network:
            raise ValueError(f"Expected a non-empty value for `network` but received {network!r}")
        if not token_address:
            raise ValueError(f"Expected a non-empty value for `token_address` but received {token_address!r}")
        return await self._get(
            f"/onchain/networks/{network}/tokens/{token_address}/holders_chart",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"days": days}, holders_chart_get_params.HoldersChartGetParams),
            ),
            cast_to=HoldersChartGetResponse,
        )


class HoldersChartResourceWithRawResponse:
    def __init__(self, holders_chart: HoldersChartResource) -> None:
        self._holders_chart = holders_chart

        self.get = to_raw_response_wrapper(
            holders_chart.get,
        )


class AsyncHoldersChartResourceWithRawResponse:
    def __init__(self, holders_chart: AsyncHoldersChartResource) -> None:
        self._holders_chart = holders_chart

        self.get = async_to_raw_response_wrapper(
            holders_chart.get,
        )


class HoldersChartResourceWithStreamingResponse:
    def __init__(self, holders_chart: HoldersChartResource) -> None:
        self._holders_chart = holders_chart

        self.get = to_streamed_response_wrapper(
            holders_chart.get,
        )


class AsyncHoldersChartResourceWithStreamingResponse:
    def __init__(self, holders_chart: AsyncHoldersChartResource) -> None:
        self._holders_chart = holders_chart

        self.get = async_to_streamed_response_wrapper(
            holders_chart.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.search import trending_get_params
from ...types.search.trending_get_response import TrendingGetResponse

__all__ = ["TrendingResource", "AsyncTrendingResource"]


class TrendingResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TrendingResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return TrendingResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TrendingResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return TrendingResourceWithStreamingResponse(self)

    def get(
        self,
        *,
        show_max: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TrendingGetResponse:
        """
        This endpoint allows you **query trending search coins, NFTs and categories on
        CoinGecko in the last 24 hours**

        Args:
          show_max:
              show max number of results available for the given type Available values:
              `coins`, `nfts`, `categories` Example: `coins` or `coins,nfts,categories`

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/search/trending",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"show_max": show_max}, trending_get_params.TrendingGetParams),
            ),
            cast_to=TrendingGetResponse,
        )


class AsyncTrendingResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTrendingResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTrendingResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTrendingResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncTrendingResourceWithStreamingResponse(self)

    async def get(
        self,
        *,
        show_max: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TrendingGetResponse:
        """
        This endpoint allows you **query trending search coins, NFTs and categories on
        CoinGecko in the last 24 hours**

        Args:
          show_max:
              show max number of results available for the given type Available values:
              `coins`, `nfts`, `categories` Example: `coins` or `coins,nfts,categories`

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/search/trending",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"show_max": show_max}, trending_get_params.TrendingGetParams),
            ),
            cast_to=TrendingGetResponse,
        )


class TrendingResourceWithRawResponse:
    def __init__(self, trending: TrendingResource) -> None:
        self._trending = trending

        self.get = to_raw_response_wrapper(
            trending.get,
        )


class AsyncTrendingResourceWithRawResponse:
    def __init__(self, trending: AsyncTrendingResource) -> None:
        self._trending = trending

        self.get = async_to_raw_response_wrapper(
            trending.get,
        )


class TrendingResourceWithStreamingResponse:
    def __init__(self, trending: TrendingResource) -> None:
        self._trending = trending

        self.get = to_streamed_response_wrapper(
            trending.get,
        )


class AsyncTrendingResourceWithStreamingResponse:
    def __init__(self, trending: AsyncTrendingResource) -> None:
        self._trending = trending

        self.get = async_to_streamed_response_wrapper(
            trending.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .ticker_get_response import TickerGetResponse as TickerGetResponse
from .market_chart_get_params import MarketChartGetParams as MarketChartGetParams
from .market_chart_get_response import MarketChartGetResponse as MarketChartGetResponse
from .contract_get_contract_address_response import (
    ContractGetContractAddressResponse as ContractGetContractAddressResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["KeyGetResponse"]


class KeyGetResponse(BaseModel):
    current_remaining_monthly_calls: Optional[float] = None

    current_total_monthly_calls: Optional[float] = None

    monthly_call_credit: Optional[float] = None

    plan: Optional[str] = None

    rate_limit_request_per_minute: Optional[float] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .._models import BaseModel

__all__ = ["ExchangeGetListResponse", "ExchangeGetListResponseItem"]


class ExchangeGetListResponseItem(BaseModel):
    id: str
    """exchange ID"""

    name: str
    """exchange name"""


ExchangeGetListResponse: TypeAlias = List[ExchangeGetListResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .pool_get_params import PoolGetParams as PoolGetParams
from .pool_get_response import PoolGetResponse as PoolGetResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["NFTGetListParams"]


class NFTGetListParams(TypedDict, total=False):
    order: Literal[
        "h24_volume_usd_asc",
        "h24_volume_usd_desc",
        "h24_volume_native_asc",
        "h24_volume_native_desc",
        "floor_price_native_asc",
        "floor_price_native_desc",
        "market_cap_native_asc",
        "market_cap_native_desc",
        "market_cap_usd_asc",
        "market_cap_usd_desc",
    ]
    """use this to sort the order of responses"""

    page: float
    """page through results"""

    per_page: float
    """total results per page Valid values: 1...250"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .pools import (
    PoolsResource,
    AsyncPoolsResource,
    PoolsResourceWithRawResponse,
    AsyncPoolsResourceWithRawResponse,
    PoolsResourceWithStreamingResponse,
    AsyncPoolsResourceWithStreamingResponse,
)
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["SearchResource", "AsyncSearchResource"]


class SearchResource(SyncAPIResource):
    @cached_property
    def pools(self) -> PoolsResource:
        return PoolsResource(self._client)

    @cached_property
    def with_raw_response(self) -> SearchResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return SearchResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SearchResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return SearchResourceWithStreamingResponse(self)


class AsyncSearchResource(AsyncAPIResource):
    @cached_property
    def pools(self) -> AsyncPoolsResource:
        return AsyncPoolsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncSearchResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSearchResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSearchResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncSearchResourceWithStreamingResponse(self)


class SearchResourceWithRawResponse:
    def __init__(self, search: SearchResource) -> None:
        self._search = search

    @cached_property
    def pools(self) -> PoolsResourceWithRawResponse:
        return PoolsResourceWithRawResponse(self._search.pools)


class AsyncSearchResourceWithRawResponse:
    def __init__(self, search: AsyncSearchResource) -> None:
        self._search = search

    @cached_property
    def pools(self) -> AsyncPoolsResourceWithRawResponse:
        return AsyncPoolsResourceWithRawResponse(self._search.pools)


class SearchResourceWithStreamingResponse:
    def __init__(self, search: SearchResource) -> None:
        self._search = search

    @cached_property
    def pools(self) -> PoolsResourceWithStreamingResponse:
        return PoolsResourceWithStreamingResponse(self._search.pools)


class AsyncSearchResourceWithStreamingResponse:
    def __init__(self, search: AsyncSearchResource) -> None:
        self._search = search

    @cached_property
    def pools(self) -> AsyncPoolsResourceWithStreamingResponse:
        return AsyncPoolsResourceWithStreamingResponse(self._search.pools)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ExchangeGetParams"]


class ExchangeGetParams(TypedDict, total=False):
    page: float
    """page through results, default: 1"""

    per_page: float
    """total results per page, default: 100 Valid values: 1...250"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.nfts.ticker_get_response import TickerGetResponse

__all__ = ["TickersResource", "AsyncTickersResource"]


class TickersResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TickersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return TickersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TickersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return TickersResourceWithStreamingResponse(self)

    def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TickerGetResponse:
        """
        This endpoint allows you to **query the latest floor price and 24hr volume of a
        NFT collection, on each NFT marketplace, e.g. OpenSea and LooksRare**

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/nfts/{id}/tickers",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TickerGetResponse,
        )


class AsyncTickersResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTickersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTickersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTickersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncTickersResourceWithStreamingResponse(self)

    async def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TickerGetResponse:
        """
        This endpoint allows you to **query the latest floor price and 24hr volume of a
        NFT collection, on each NFT marketplace, e.g. OpenSea and LooksRare**

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/nfts/{id}/tickers",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TickerGetResponse,
        )


class TickersResourceWithRawResponse:
    def __init__(self, tickers: TickersResource) -> None:
        self._tickers = tickers

        self.get = to_raw_response_wrapper(
            tickers.get,
        )


class AsyncTickersResourceWithRawResponse:
    def __init__(self, tickers: AsyncTickersResource) -> None:
        self._tickers = tickers

        self.get = async_to_raw_response_wrapper(
            tickers.get,
        )


class TickersResourceWithStreamingResponse:
    def __init__(self, tickers: TickersResource) -> None:
        self._tickers = tickers

        self.get = to_streamed_response_wrapper(
            tickers.get,
        )


class AsyncTickersResourceWithStreamingResponse:
    def __init__(self, tickers: AsyncTickersResource) -> None:
        self._tickers = tickers

        self.get = async_to_streamed_response_wrapper(
            tickers.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .network_get_params import NetworkGetParams as NetworkGetParams
from .category_get_params import CategoryGetParams as CategoryGetParams
from .network_get_response import NetworkGetResponse as NetworkGetResponse
from .category_get_response import CategoryGetResponse as CategoryGetResponse
from .category_get_pools_params import CategoryGetPoolsParams as CategoryGetPoolsParams
from .category_get_pools_response import CategoryGetPoolsResponse as CategoryGetPoolsResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .pools import (
    PoolsResource,
    AsyncPoolsResource,
    PoolsResourceWithRawResponse,
    AsyncPoolsResourceWithRawResponse,
    PoolsResourceWithStreamingResponse,
    AsyncPoolsResourceWithStreamingResponse,
)
from .search import (
    SearchResource,
    AsyncSearchResource,
    SearchResourceWithRawResponse,
    AsyncSearchResourceWithRawResponse,
    SearchResourceWithStreamingResponse,
    AsyncSearchResourceWithStreamingResponse,
)

__all__ = [
    "PoolsResource",
    "AsyncPoolsResource",
    "PoolsResourceWithRawResponse",
    "AsyncPoolsResourceWithRawResponse",
    "PoolsResourceWithStreamingResponse",
    "AsyncPoolsResourceWithStreamingResponse",
    "SearchResource",
    "AsyncSearchResource",
    "SearchResourceWithRawResponse",
    "AsyncSearchResourceWithRawResponse",
    "SearchResourceWithStreamingResponse",
    "AsyncSearchResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from .market_cap_chart import (
    MarketCapChartResource,
    AsyncMarketCapChartResource,
    MarketCapChartResourceWithRawResponse,
    AsyncMarketCapChartResourceWithRawResponse,
    MarketCapChartResourceWithStreamingResponse,
    AsyncMarketCapChartResourceWithStreamingResponse,
)
from .decentralized_finance_defi import (
    DecentralizedFinanceDefiResource,
    AsyncDecentralizedFinanceDefiResource,
    DecentralizedFinanceDefiResourceWithRawResponse,
    AsyncDecentralizedFinanceDefiResourceWithRawResponse,
    DecentralizedFinanceDefiResourceWithStreamingResponse,
    AsyncDecentralizedFinanceDefiResourceWithStreamingResponse,
)
from ...types.global_get_response import GlobalGetResponse

__all__ = ["GlobalResource", "AsyncGlobalResource"]


class GlobalResource(SyncAPIResource):
    @cached_property
    def decentralized_finance_defi(self) -> DecentralizedFinanceDefiResource:
        return DecentralizedFinanceDefiResource(self._client)

    @cached_property
    def market_cap_chart(self) -> MarketCapChartResource:
        return MarketCapChartResource(self._client)

    @cached_property
    def with_raw_response(self) -> GlobalResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return GlobalResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> GlobalResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return GlobalResourceWithStreamingResponse(self)

    def get(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GlobalGetResponse:
        """
        This endpoint allows you **query cryptocurrency global data including active
        cryptocurrencies, markets, total crypto market cap and etc**
        """
        return self._get(
            "/global",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GlobalGetResponse,
        )


class AsyncGlobalResource(AsyncAPIResource):
    @cached_property
    def decentralized_finance_defi(self) -> AsyncDecentralizedFinanceDefiResource:
        return AsyncDecentralizedFinanceDefiResource(self._client)

    @cached_property
    def market_cap_chart(self) -> AsyncMarketCapChartResource:
        return AsyncMarketCapChartResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncGlobalResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncGlobalResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncGlobalResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncGlobalResourceWithStreamingResponse(self)

    async def get(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GlobalGetResponse:
        """
        This endpoint allows you **query cryptocurrency global data including active
        cryptocurrencies, markets, total crypto market cap and etc**
        """
        return await self._get(
            "/global",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GlobalGetResponse,
        )


class GlobalResourceWithRawResponse:
    def __init__(self, global_: GlobalResource) -> None:
        self._global_ = global_

        self.get = to_raw_response_wrapper(
            global_.get,
        )

    @cached_property
    def decentralized_finance_defi(self) -> DecentralizedFinanceDefiResourceWithRawResponse:
        return DecentralizedFinanceDefiResourceWithRawResponse(self._global_.decentralized_finance_defi)

    @cached_property
    def market_cap_chart(self) -> MarketCapChartResourceWithRawResponse:
        return MarketCapChartResourceWithRawResponse(self._global_.market_cap_chart)


class AsyncGlobalResourceWithRawResponse:
    def __init__(self, global_: AsyncGlobalResource) -> None:
        self._global_ = global_

        self.get = async_to_raw_response_wrapper(
            global_.get,
        )

    @cached_property
    def decentralized_finance_defi(self) -> AsyncDecentralizedFinanceDefiResourceWithRawResponse:
        return AsyncDecentralizedFinanceDefiResourceWithRawResponse(self._global_.decentralized_finance_defi)

    @cached_property
    def market_cap_chart(self) -> AsyncMarketCapChartResourceWithRawResponse:
        return AsyncMarketCapChartResourceWithRawResponse(self._global_.market_cap_chart)


class GlobalResourceWithStreamingResponse:
    def __init__(self, global_: GlobalResource) -> None:
        self._global_ = global_

        self.get = to_streamed_response_wrapper(
            global_.get,
        )

    @cached_property
    def decentralized_finance_defi(self) -> DecentralizedFinanceDefiResourceWithStreamingResponse:
        return DecentralizedFinanceDefiResourceWithStreamingResponse(self._global_.decentralized_finance_defi)

    @cached_property
    def market_cap_chart(self) -> MarketCapChartResourceWithStreamingResponse:
        return MarketCapChartResourceWithStreamingResponse(self._global_.market_cap_chart)


class AsyncGlobalResourceWithStreamingResponse:
    def __init__(self, global_: AsyncGlobalResource) -> None:
        self._global_ = global_

        self.get = async_to_streamed_response_wrapper(
            global_.get,
        )

    @cached_property
    def decentralized_finance_defi(self) -> AsyncDecentralizedFinanceDefiResourceWithStreamingResponse:
        return AsyncDecentralizedFinanceDefiResourceWithStreamingResponse(self._global_.decentralized_finance_defi)

    @cached_property
    def market_cap_chart(self) -> AsyncMarketCapChartResourceWithStreamingResponse:
        return AsyncMarketCapChartResourceWithStreamingResponse(self._global_.market_cap_chart)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional

from ....._models import BaseModel

__all__ = ["TokenPriceGetAddressesResponse", "Data", "DataAttributes"]


class DataAttributes(BaseModel):
    token_prices: Optional[Dict[str, str]] = None


class Data(BaseModel):
    id: Optional[str] = None

    attributes: Optional[DataAttributes] = None

    type: Optional[str] = None


class TokenPriceGetAddressesResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ....._models import BaseModel

__all__ = ["TradeGetResponse", "Data", "DataAttributes"]


class DataAttributes(BaseModel):
    block_number: Optional[int] = None

    block_timestamp: Optional[str] = None

    from_token_address: Optional[str] = None

    from_token_amount: Optional[str] = None

    kind: Optional[str] = None

    pool_address: Optional[str] = None

    pool_dex: Optional[str] = None

    price_from_in_currency_token: Optional[str] = None

    price_from_in_usd: Optional[str] = None

    price_to_in_currency_token: Optional[str] = None

    price_to_in_usd: Optional[str] = None

    to_token_address: Optional[str] = None

    to_token_amount: Optional[str] = None

    tx_from_address: Optional[str] = None

    tx_hash: Optional[str] = None

    volume_in_usd: Optional[str] = None


class Data(BaseModel):
    id: Optional[str] = None

    attributes: Optional[DataAttributes] = None

    type: Optional[str] = None


class TradeGetResponse(BaseModel):
    data: Optional[List[Data]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from .public_treasury import (
    PublicTreasuryResource,
    AsyncPublicTreasuryResource,
    PublicTreasuryResourceWithRawResponse,
    AsyncPublicTreasuryResourceWithRawResponse,
    PublicTreasuryResourceWithStreamingResponse,
    AsyncPublicTreasuryResourceWithStreamingResponse,
)

__all__ = ["CompaniesResource", "AsyncCompaniesResource"]


class CompaniesResource(SyncAPIResource):
    @cached_property
    def public_treasury(self) -> PublicTreasuryResource:
        return PublicTreasuryResource(self._client)

    @cached_property
    def with_raw_response(self) -> CompaniesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return CompaniesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CompaniesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return CompaniesResourceWithStreamingResponse(self)


class AsyncCompaniesResource(AsyncAPIResource):
    @cached_property
    def public_treasury(self) -> AsyncPublicTreasuryResource:
        return AsyncPublicTreasuryResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncCompaniesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncCompaniesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCompaniesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncCompaniesResourceWithStreamingResponse(self)


class CompaniesResourceWithRawResponse:
    def __init__(self, companies: CompaniesResource) -> None:
        self._companies = companies

    @cached_property
    def public_treasury(self) -> PublicTreasuryResourceWithRawResponse:
        return PublicTreasuryResourceWithRawResponse(self._companies.public_treasury)


class AsyncCompaniesResourceWithRawResponse:
    def __init__(self, companies: AsyncCompaniesResource) -> None:
        self._companies = companies

    @cached_property
    def public_treasury(self) -> AsyncPublicTreasuryResourceWithRawResponse:
        return AsyncPublicTreasuryResourceWithRawResponse(self._companies.public_treasury)


class CompaniesResourceWithStreamingResponse:
    def __init__(self, companies: CompaniesResource) -> None:
        self._companies = companies

    @cached_property
    def public_treasury(self) -> PublicTreasuryResourceWithStreamingResponse:
        return PublicTreasuryResourceWithStreamingResponse(self._companies.public_treasury)


class AsyncCompaniesResourceWithStreamingResponse:
    def __init__(self, companies: AsyncCompaniesResource) -> None:
        self._companies = companies

    @cached_property
    def public_treasury(self) -> AsyncPublicTreasuryResourceWithStreamingResponse:
        return AsyncPublicTreasuryResourceWithStreamingResponse(self._companies.public_treasury)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["CoinGetIDParams"]


class CoinGetIDParams(TypedDict, total=False):
    community_data: bool
    """include community data, default: true"""

    developer_data: bool
    """include developer data, default: true"""

    dex_pair_format: Literal["contract_address", "symbol"]
    """
    set to `symbol` to display DEX pair base and target as symbols, default:
    `contract_address`
    """

    localization: bool
    """include all the localized languages in the response, default: true"""

    market_data: bool
    """include market data, default: true"""

    sparkline: bool
    """include sparkline 7 days data, default: false"""

    tickers: bool
    """include tickers data, default: true"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["CategoryGetParams"]


class CategoryGetParams(TypedDict, total=False):
    order: Literal[
        "market_cap_desc",
        "market_cap_asc",
        "name_desc",
        "name_asc",
        "market_cap_change_24h_desc",
        "market_cap_change_24h_asc",
    ]
    """sort results by field, default: market_cap_desc"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["TokenPriceGetAddressesParams"]


class TokenPriceGetAddressesParams(TypedDict, total=False):
    network: Required[str]

    include_24hr_price_change: bool
    """include 24hr price change, default: false"""

    include_24hr_vol: bool
    """include 24hr volume, default: false"""

    include_market_cap: bool
    """include market capitalization, default: false"""

    include_total_reserve_in_usd: bool
    """include total reserve in USD, default: false"""

    mcap_fdv_fallback: bool
    """return FDV if market cap is not available, default: false"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ....._models import BaseModel

__all__ = ["OhlcvGetTimeframeResponse", "Data", "DataAttributes", "Meta", "MetaBase", "MetaQuote"]


class DataAttributes(BaseModel):
    ohlcv_list: Optional[List[List[float]]] = None


class Data(BaseModel):
    id: Optional[str] = None

    attributes: Optional[DataAttributes] = None

    type: Optional[str] = None


class MetaBase(BaseModel):
    address: Optional[str] = None

    coingecko_coin_id: Optional[str] = None

    name: Optional[str] = None

    symbol: Optional[str] = None


class MetaQuote(BaseModel):
    address: Optional[str] = None

    coingecko_coin_id: Optional[str] = None

    name: Optional[str] = None

    symbol: Optional[str] = None


class Meta(BaseModel):
    base: Optional[MetaBase] = None

    quote: Optional[MetaQuote] = None


class OhlcvGetTimeframeResponse(BaseModel):
    data: Optional[Data] = None

    meta: Optional[Meta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["TotalSupplyChartGetParams"]


class TotalSupplyChartGetParams(TypedDict, total=False):
    days: Required[str]
    """data up to number of days ago Valid values: any integer or `max`"""

    interval: Literal["daily"]
    """data interval"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel

__all__ = ["CategoryGetResponse"]


class CategoryGetResponse(BaseModel):
    id: Optional[str] = None
    """category ID"""

    content: Optional[str] = None
    """category description"""

    market_cap: Optional[float] = None
    """category market cap"""

    market_cap_change_24h: Optional[float] = None
    """category market cap change in 24 hours"""

    name: Optional[str] = None
    """category name"""

    top_3_coins: Optional[List[str]] = None
    """images of top 3 coins in the category"""

    top_3_coins_id: Optional[List[str]] = None
    """IDs of top 3 coins in the category"""

    updated_at: Optional[str] = None
    """category last updated time"""

    volume_24h: Optional[float] = None
    """category volume in 24 hours"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["HistoryGetParams"]


class HistoryGetParams(TypedDict, total=False):
    date: Required[str]
    """the date of data snapshot Format: `dd-mm-yyyy`"""

    localization: bool
    """include all the localized languages in response, default: true"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["TokenListGetAllJsonResponse", "Token"]


class Token(BaseModel):
    address: Optional[str] = None
    """token contract address"""

    chain_id: Optional[float] = FieldInfo(alias="chainId", default=None)
    """chainlist's chain ID"""

    decimals: Optional[float] = None
    """token decimals"""

    logo_uri: Optional[str] = FieldInfo(alias="logoURI", default=None)
    """token image url"""

    name: Optional[str] = None
    """token name"""

    symbol: Optional[str] = None
    """token symbol"""


class TokenListGetAllJsonResponse(BaseModel):
    keywords: Optional[List[str]] = None

    logo_uri: Optional[str] = FieldInfo(alias="logoURI", default=None)

    name: Optional[str] = None

    timestamp: Optional[datetime] = None

    tokens: Optional[List[Token]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["HoldersChartGetParams"]


class HoldersChartGetParams(TypedDict, total=False):
    network: Required[str]

    days: Literal["7", "30", "max"]
    """number of days to return the historical token holders chart Default value: 7"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["GlobalGetResponse", "Data", "DataMarketCapPercentage", "DataTotalMarketCap", "DataTotalVolume"]


class DataMarketCapPercentage(BaseModel):
    btc: Optional[float] = None

    eth: Optional[float] = None


class DataTotalMarketCap(BaseModel):
    btc: Optional[float] = None

    eth: Optional[float] = None


class DataTotalVolume(BaseModel):
    btc: Optional[float] = None

    eth: Optional[float] = None


class Data(BaseModel):
    active_cryptocurrencies: Optional[float] = None
    """number of active cryptocurrencies"""

    ended_icos: Optional[float] = None
    """number of ended icos"""

    market_cap_change_percentage_24h_usd: Optional[float] = None
    """cryptocurrencies market cap change percentage in 24 hours in usd"""

    market_cap_percentage: Optional[DataMarketCapPercentage] = None
    """cryptocurrencies market cap percentage"""

    markets: Optional[float] = None
    """number of exchanges"""

    ongoing_icos: Optional[float] = None
    """number of ongoing icos"""

    total_market_cap: Optional[DataTotalMarketCap] = None
    """cryptocurrencies total market cap"""

    total_volume: Optional[DataTotalVolume] = None
    """cryptocurrencies total volume"""

    upcoming_icos: Optional[float] = None
    """number of upcoming icos"""

    updated_at: Optional[float] = None


class GlobalGetResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ...._models import BaseModel

__all__ = [
    "TokenGetAddressResponse",
    "Data",
    "DataAttributes",
    "DataAttributesVolumeUsd",
    "DataRelationships",
    "DataRelationshipsTopPools",
    "DataRelationshipsTopPoolsData",
    "Included",
    "IncludedAttributes",
    "IncludedAttributesPriceChangePercentage",
    "IncludedAttributesTransactions",
    "IncludedAttributesTransactionsH1",
    "IncludedAttributesTransactionsH24",
    "IncludedAttributesTransactionsM15",
    "IncludedAttributesTransactionsM30",
    "IncludedAttributesTransactionsM5",
    "IncludedAttributesVolumeUsd",
    "IncludedRelationships",
    "IncludedRelationshipsBaseToken",
    "IncludedRelationshipsBaseTokenData",
    "IncludedRelationshipsDex",
    "IncludedRelationshipsDexData",
    "IncludedRelationshipsQuoteToken",
    "IncludedRelationshipsQuoteTokenData",
]


class DataAttributesVolumeUsd(BaseModel):
    h24: Optional[str] = None


class DataAttributes(BaseModel):
    address: Optional[str] = None

    coingecko_coin_id: Optional[str] = None

    decimals: Optional[int] = None

    fdv_usd: Optional[str] = None

    image_url: Optional[str] = None

    market_cap_usd: Optional[str] = None

    name: Optional[str] = None

    normalized_total_supply: Optional[str] = None

    price_usd: Optional[str] = None

    symbol: Optional[str] = None

    total_reserve_in_usd: Optional[str] = None

    total_supply: Optional[str] = None

    volume_usd: Optional[DataAttributesVolumeUsd] = None


class DataRelationshipsTopPoolsData(BaseModel):
    id: Optional[str] = None

    type: Optional[str] = None


class DataRelationshipsTopPools(BaseModel):
    data: Optional[List[DataRelationshipsTopPoolsData]] = None


class DataRelationships(BaseModel):
    top_pools: Optional[DataRelationshipsTopPools] = None


class Data(BaseModel):
    id: Optional[str] = None

    attributes: Optional[DataAttributes] = None

    relationships: Optional[DataRelationships] = None

    type: Optional[str] = None


class IncludedAttributesPriceChangePercentage(BaseModel):
    h1: Optional[str] = None

    h24: Optional[str] = None

    h6: Optional[str] = None

    m15: Optional[str] = None

    m30: Optional[str] = None

    m5: Optional[str] = None


class IncludedAttributesTransactionsH1(BaseModel):
    buyers: Optional[int] = None

    buys: Optional[int] = None

    sellers: Optional[int] = None

    sells: Optional[int] = None


class IncludedAttributesTransactionsH24(BaseModel):
    buyers: Optional[int] = None

    buys: Optional[int] = None

    sellers: Optional[int] = None

    sells: Optional[int] = None


class IncludedAttributesTransactionsM15(BaseModel):
    buyers: Optional[int] = None

    buys: Optional[int] = None

    sellers: Optional[int] = None

    sells: Optional[int] = None


class IncludedAttributesTransactionsM30(BaseModel):
    buyers: Optional[int] = None

    buys: Optional[int] = None

    sellers: Optional[int] = None

    sells: Optional[int] = None


class IncludedAttributesTransactionsM5(BaseModel):
    buyers: Optional[int] = None

    buys: Optional[int] = None

    sellers: Optional[int] = None

    sells: Optional[int] = None


class IncludedAttributesTransactions(BaseModel):
    h1: Optional[IncludedAttributesTransactionsH1] = None

    h24: Optional[IncludedAttributesTransactionsH24] = None

    m15: Optional[IncludedAttributesTransactionsM15] = None

    m30: Optional[IncludedAttributesTransactionsM30] = None

    m5: Optional[IncludedAttributesTransactionsM5] = None


class IncludedAttributesVolumeUsd(BaseModel):
    h1: Optional[str] = None

    h24: Optional[str] = None

    h6: Optional[str] = None

    m15: Optional[str] = None

    m30: Optional[str] = None

    m5: Optional[str] = None


class IncludedAttributes(BaseModel):
    address: Optional[str] = None

    base_token_price_native_currency: Optional[str] = None

    base_token_price_quote_token: Optional[str] = None

    base_token_price_usd: Optional[str] = None

    fdv_usd: Optional[str] = None

    market_cap_usd: Optional[str] = None

    name: Optional[str] = None

    pool_created_at: Optional[str] = None

    price_change_percentage: Optional[IncludedAttributesPriceChangePercentage] = None

    quote_token_price_base_token: Optional[str] = None

    quote_token_price_native_currency: Optional[str] = None

    quote_token_price_usd: Optional[str] = None

    reserve_in_usd: Optional[str] = None

    token_price_usd: Optional[str] = None

    transactions: Optional[IncludedAttributesTransactions] = None

    volume_usd: Optional[IncludedAttributesVolumeUsd] = None


class IncludedRelationshipsBaseTokenData(BaseModel):
    id: Optional[str] = None

    type: Optional[str] = None


class IncludedRelationshipsBaseToken(BaseModel):
    data: Optional[IncludedRelationshipsBaseTokenData] = None


class IncludedRelationshipsDexData(BaseModel):
    id: Optional[str] = None

    type: Optional[str] = None


class IncludedRelationshipsDex(BaseModel):
    data: Optional[IncludedRelationshipsDexData] = None


class IncludedRelationshipsQuoteTokenData(BaseModel):
    id: Optional[str] = None

    type: Optional[str] = None


class IncludedRelationshipsQuoteToken(BaseModel):
    data: Optional[IncludedRelationshipsQuoteTokenData] = None


class IncludedRelationships(BaseModel):
    base_token: Optional[IncludedRelationshipsBaseToken] = None

    dex: Optional[IncludedRelationshipsDex] = None

    quote_token: Optional[IncludedRelationshipsQuoteToken] = None


class Included(BaseModel):
    id: Optional[str] = None

    attributes: Optional[IncludedAttributes] = None

    relationships: Optional[IncludedRelationships] = None

    type: Optional[str] = None


class TokenGetAddressResponse(BaseModel):
    data: Optional[Data] = None

    included: Optional[List[Included]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .megafilter_get_params import MegafilterGetParams as MegafilterGetParams
from .megafilter_get_response import MegafilterGetResponse as MegafilterGetResponse
from .trending_search_get_params import TrendingSearchGetParams as TrendingSearchGetParams
from .trending_search_get_response import TrendingSearchGetResponse as TrendingSearchGetResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .dexes import (
    DexesResource,
    AsyncDexesResource,
    DexesResourceWithRawResponse,
    AsyncDexesResourceWithRawResponse,
    DexesResourceWithStreamingResponse,
    AsyncDexesResourceWithStreamingResponse,
)
from ...._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ...._utils import maybe_transform, async_maybe_transform
from .new_pools import (
    NewPoolsResource,
    AsyncNewPoolsResource,
    NewPoolsResourceWithRawResponse,
    AsyncNewPoolsResourceWithRawResponse,
    NewPoolsResourceWithStreamingResponse,
    AsyncNewPoolsResourceWithStreamingResponse,
)
from ...._compat import cached_property
from .pools.pools import (
    PoolsResource,
    AsyncPoolsResource,
    PoolsResourceWithRawResponse,
    AsyncPoolsResourceWithRawResponse,
    PoolsResourceWithStreamingResponse,
    AsyncPoolsResourceWithStreamingResponse,
)
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .tokens.tokens import (
    TokensResource,
    AsyncTokensResource,
    TokensResourceWithRawResponse,
    AsyncTokensResourceWithRawResponse,
    TokensResourceWithStreamingResponse,
    AsyncTokensResourceWithStreamingResponse,
)
from .trending_pools import (
    TrendingPoolsResource,
    AsyncTrendingPoolsResource,
    TrendingPoolsResourceWithRawResponse,
    AsyncTrendingPoolsResourceWithRawResponse,
    TrendingPoolsResourceWithStreamingResponse,
    AsyncTrendingPoolsResourceWithStreamingResponse,
)
from ...._base_client import make_request_options
from ....types.onchain import network_get_params
from ....types.onchain.network_get_response import NetworkGetResponse

__all__ = ["NetworksResource", "AsyncNetworksResource"]


class NetworksResource(SyncAPIResource):
    @cached_property
    def new_pools(self) -> NewPoolsResource:
        return NewPoolsResource(self._client)

    @cached_property
    def trending_pools(self) -> TrendingPoolsResource:
        return TrendingPoolsResource(self._client)

    @cached_property
    def dexes(self) -> DexesResource:
        return DexesResource(self._client)

    @cached_property
    def pools(self) -> PoolsResource:
        return PoolsResource(self._client)

    @cached_property
    def tokens(self) -> TokensResource:
        return TokensResource(self._client)

    @cached_property
    def with_raw_response(self) -> NetworksResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return NetworksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> NetworksResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return NetworksResourceWithStreamingResponse(self)

    def get(
        self,
        *,
        page: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NetworkGetResponse:
        """
        This endpoint allows you to **query all the supported networks on
        GeckoTerminal**

        Args:
          page: page through results Default value: 1

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/onchain/networks",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"page": page}, network_get_params.NetworkGetParams),
            ),
            cast_to=NetworkGetResponse,
        )


class AsyncNetworksResource(AsyncAPIResource):
    @cached_property
    def new_pools(self) -> AsyncNewPoolsResource:
        return AsyncNewPoolsResource(self._client)

    @cached_property
    def trending_pools(self) -> AsyncTrendingPoolsResource:
        return AsyncTrendingPoolsResource(self._client)

    @cached_property
    def dexes(self) -> AsyncDexesResource:
        return AsyncDexesResource(self._client)

    @cached_property
    def pools(self) -> AsyncPoolsResource:
        return AsyncPoolsResource(self._client)

    @cached_property
    def tokens(self) -> AsyncTokensResource:
        return AsyncTokensResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncNetworksResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncNetworksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncNetworksResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncNetworksResourceWithStreamingResponse(self)

    async def get(
        self,
        *,
        page: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NetworkGetResponse:
        """
        This endpoint allows you to **query all the supported networks on
        GeckoTerminal**

        Args:
          page: page through results Default value: 1

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/onchain/networks",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"page": page}, network_get_params.NetworkGetParams),
            ),
            cast_to=NetworkGetResponse,
        )


class NetworksResourceWithRawResponse:
    def __init__(self, networks: NetworksResource) -> None:
        self._networks = networks

        self.get = to_raw_response_wrapper(
            networks.get,
        )

    @cached_property
    def new_pools(self) -> NewPoolsResourceWithRawResponse:
        return NewPoolsResourceWithRawResponse(self._networks.new_pools)

    @cached_property
    def trending_pools(self) -> TrendingPoolsResourceWithRawResponse:
        return TrendingPoolsResourceWithRawResponse(self._networks.trending_pools)

    @cached_property
    def dexes(self) -> DexesResourceWithRawResponse:
        return DexesResourceWithRawResponse(self._networks.dexes)

    @cached_property
    def pools(self) -> PoolsResourceWithRawResponse:
        return PoolsResourceWithRawResponse(self._networks.pools)

    @cached_property
    def tokens(self) -> TokensResourceWithRawResponse:
        return TokensResourceWithRawResponse(self._networks.tokens)


class AsyncNetworksResourceWithRawResponse:
    def __init__(self, networks: AsyncNetworksResource) -> None:
        self._networks = networks

        self.get = async_to_raw_response_wrapper(
            networks.get,
        )

    @cached_property
    def new_pools(self) -> AsyncNewPoolsResourceWithRawResponse:
        return AsyncNewPoolsResourceWithRawResponse(self._networks.new_pools)

    @cached_property
    def trending_pools(self) -> AsyncTrendingPoolsResourceWithRawResponse:
        return AsyncTrendingPoolsResourceWithRawResponse(self._networks.trending_pools)

    @cached_property
    def dexes(self) -> AsyncDexesResourceWithRawResponse:
        return AsyncDexesResourceWithRawResponse(self._networks.dexes)

    @cached_property
    def pools(self) -> AsyncPoolsResourceWithRawResponse:
        return AsyncPoolsResourceWithRawResponse(self._networks.pools)

    @cached_property
    def tokens(self) -> AsyncTokensResourceWithRawResponse:
        return AsyncTokensResourceWithRawResponse(self._networks.tokens)


class NetworksResourceWithStreamingResponse:
    def __init__(self, networks: NetworksResource) -> None:
        self._networks = networks

        self.get = to_streamed_response_wrapper(
            networks.get,
        )

    @cached_property
    def new_pools(self) -> NewPoolsResourceWithStreamingResponse:
        return NewPoolsResourceWithStreamingResponse(self._networks.new_pools)

    @cached_property
    def trending_pools(self) -> TrendingPoolsResourceWithStreamingResponse:
        return TrendingPoolsResourceWithStreamingResponse(self._networks.trending_pools)

    @cached_property
    def dexes(self) -> DexesResourceWithStreamingResponse:
        return DexesResourceWithStreamingResponse(self._networks.dexes)

    @cached_property
    def pools(self) -> PoolsResourceWithStreamingResponse:
        return PoolsResourceWithStreamingResponse(self._networks.pools)

    @cached_property
    def tokens(self) -> TokensResourceWithStreamingResponse:
        return TokensResourceWithStreamingResponse(self._networks.tokens)


class AsyncNetworksResourceWithStreamingResponse:
    def __init__(self, networks: AsyncNetworksResource) -> None:
        self._networks = networks

        self.get = async_to_streamed_response_wrapper(
            networks.get,
        )

    @cached_property
    def new_pools(self) -> AsyncNewPoolsResourceWithStreamingResponse:
        return AsyncNewPoolsResourceWithStreamingResponse(self._networks.new_pools)

    @cached_property
    def trending_pools(self) -> AsyncTrendingPoolsResourceWithStreamingResponse:
        return AsyncTrendingPoolsResourceWithStreamingResponse(self._networks.trending_pools)

    @cached_property
    def dexes(self) -> AsyncDexesResourceWithStreamingResponse:
        return AsyncDexesResourceWithStreamingResponse(self._networks.dexes)

    @cached_property
    def pools(self) -> AsyncPoolsResourceWithStreamingResponse:
        return AsyncPoolsResourceWithStreamingResponse(self._networks.pools)

    @cached_property
    def tokens(self) -> AsyncTokensResourceWithStreamingResponse:
        return AsyncTokensResourceWithStreamingResponse(self._networks.tokens)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.coins import history_get_params
from ..._base_client import make_request_options
from ...types.coins.history_get_response import HistoryGetResponse

__all__ = ["HistoryResource", "AsyncHistoryResource"]


class HistoryResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> HistoryResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return HistoryResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> HistoryResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return HistoryResourceWithStreamingResponse(self)

    def get(
        self,
        id: str,
        *,
        date: str,
        localization: bool | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> HistoryGetResponse:
        """
        This endpoint allows you to **query the historical data (price, market cap,
        24hrs volume, ...) at a given date for a coin based on a particular coin ID**

        Args:
          date: the date of data snapshot Format: `dd-mm-yyyy`

          localization: include all the localized languages in response, default: true

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/coins/{id}/history",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "date": date,
                        "localization": localization,
                    },
                    history_get_params.HistoryGetParams,
                ),
            ),
            cast_to=HistoryGetResponse,
        )


class AsyncHistoryResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncHistoryResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncHistoryResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncHistoryResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncHistoryResourceWithStreamingResponse(self)

    async def get(
        self,
        id: str,
        *,
        date: str,
        localization: bool | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> HistoryGetResponse:
        """
        This endpoint allows you to **query the historical data (price, market cap,
        24hrs volume, ...) at a given date for a coin based on a particular coin ID**

        Args:
          date: the date of data snapshot Format: `dd-mm-yyyy`

          localization: include all the localized languages in response, default: true

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/coins/{id}/history",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "date": date,
                        "localization": localization,
                    },
                    history_get_params.HistoryGetParams,
                ),
            ),
            cast_to=HistoryGetResponse,
        )


class HistoryResourceWithRawResponse:
    def __init__(self, history: HistoryResource) -> None:
        self._history = history

        self.get = to_raw_response_wrapper(
            history.get,
        )


class AsyncHistoryResourceWithRawResponse:
    def __init__(self, history: AsyncHistoryResource) -> None:
        self._history = history

        self.get = async_to_raw_response_wrapper(
            history.get,
        )


class HistoryResourceWithStreamingResponse:
    def __init__(self, history: HistoryResource) -> None:
        self._history = history

        self.get = to_streamed_response_wrapper(
            history.get,
        )


class AsyncHistoryResourceWithStreamingResponse:
    def __init__(self, history: AsyncHistoryResource) -> None:
        self._history = history

        self.get = async_to_streamed_response_wrapper(
            history.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional
from typing_extensions import TypeAlias

from ..._models import BaseModel

__all__ = ["PriceGetResponse", "PriceGetResponseItem"]


class PriceGetResponseItem(BaseModel):
    last_updated_at: Optional[float] = None
    """last updated timestamp"""

    usd: Optional[float] = None
    """price in USD"""

    usd_24h_change: Optional[float] = None
    """24hr change in USD"""

    usd_24h_vol: Optional[float] = None
    """24hr volume in USD"""

    usd_market_cap: Optional[float] = None
    """market cap in USD"""


PriceGetResponse: TypeAlias = Dict[str, PriceGetResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.exchanges import volume_chart_get_params, volume_chart_get_range_params
from ...types.exchanges.volume_chart_get_response import VolumeChartGetResponse
from ...types.exchanges.volume_chart_get_range_response import VolumeChartGetRangeResponse

__all__ = ["VolumeChartResource", "AsyncVolumeChartResource"]


class VolumeChartResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> VolumeChartResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return VolumeChartResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> VolumeChartResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return VolumeChartResourceWithStreamingResponse(self)

    def get(
        self,
        id: str,
        *,
        days: Literal["1", "7", "14", "30", "90", "180", "365"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> VolumeChartGetResponse:
        """
        This endpoint allows you to **query the historical volume chart data with time
        in UNIX and trading volume data in BTC based on exchange’s ID**

        Args:
          days: data up to number of days ago

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/exchanges/{id}/volume_chart",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"days": days}, volume_chart_get_params.VolumeChartGetParams),
            ),
            cast_to=VolumeChartGetResponse,
        )

    def get_range(
        self,
        id: str,
        *,
        from_: float,
        to: float,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> VolumeChartGetRangeResponse:
        """
        This endpoint allows you to **query the historical volume chart data in BTC by
        specifying date range in UNIX based on exchange’s ID**

        Args:
          from_: starting date in UNIX timestamp

          to: ending date in UNIX timestamp

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/exchanges/{id}/volume_chart/range",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "from_": from_,
                        "to": to,
                    },
                    volume_chart_get_range_params.VolumeChartGetRangeParams,
                ),
            ),
            cast_to=VolumeChartGetRangeResponse,
        )


class AsyncVolumeChartResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncVolumeChartResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncVolumeChartResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncVolumeChartResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncVolumeChartResourceWithStreamingResponse(self)

    async def get(
        self,
        id: str,
        *,
        days: Literal["1", "7", "14", "30", "90", "180", "365"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> VolumeChartGetResponse:
        """
        This endpoint allows you to **query the historical volume chart data with time
        in UNIX and trading volume data in BTC based on exchange’s ID**

        Args:
          days: data up to number of days ago

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/exchanges/{id}/volume_chart",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"days": days}, volume_chart_get_params.VolumeChartGetParams),
            ),
            cast_to=VolumeChartGetResponse,
        )

    async def get_range(
        self,
        id: str,
        *,
        from_: float,
        to: float,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> VolumeChartGetRangeResponse:
        """
        This endpoint allows you to **query the historical volume chart data in BTC by
        specifying date range in UNIX based on exchange’s ID**

        Args:
          from_: starting date in UNIX timestamp

          to: ending date in UNIX timestamp

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/exchanges/{id}/volume_chart/range",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "from_": from_,
                        "to": to,
                    },
                    volume_chart_get_range_params.VolumeChartGetRangeParams,
                ),
            ),
            cast_to=VolumeChartGetRangeResponse,
        )


class VolumeChartResourceWithRawResponse:
    def __init__(self, volume_chart: VolumeChartResource) -> None:
        self._volume_chart = volume_chart

        self.get = to_raw_response_wrapper(
            volume_chart.get,
        )
        self.get_range = to_raw_response_wrapper(
            volume_chart.get_range,
        )


class AsyncVolumeChartResourceWithRawResponse:
    def __init__(self, volume_chart: AsyncVolumeChartResource) -> None:
        self._volume_chart = volume_chart

        self.get = async_to_raw_response_wrapper(
            volume_chart.get,
        )
        self.get_range = async_to_raw_response_wrapper(
            volume_chart.get_range,
        )


class VolumeChartResourceWithStreamingResponse:
    def __init__(self, volume_chart: VolumeChartResource) -> None:
        self._volume_chart = volume_chart

        self.get = to_streamed_response_wrapper(
            volume_chart.get,
        )
        self.get_range = to_streamed_response_wrapper(
            volume_chart.get_range,
        )


class AsyncVolumeChartResourceWithStreamingResponse:
    def __init__(self, volume_chart: AsyncVolumeChartResource) -> None:
        self._volume_chart = volume_chart

        self.get = async_to_streamed_response_wrapper(
            volume_chart.get,
        )
        self.get_range = async_to_streamed_response_wrapper(
            volume_chart.get_range,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .info_recently_updated_get_params import InfoRecentlyUpdatedGetParams as InfoRecentlyUpdatedGetParams
from .info_recently_updated_get_response import InfoRecentlyUpdatedGetResponse as InfoRecentlyUpdatedGetResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.coins import list_get_params
from ..._base_client import make_request_options
from ...types.coins.list_get_response import ListGetResponse
from ...types.coins.list_get_new_response import ListGetNewResponse

__all__ = ["ListResource", "AsyncListResource"]


class ListResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ListResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return ListResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ListResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return ListResourceWithStreamingResponse(self)

    def get(
        self,
        *,
        include_platform: bool | NotGiven = NOT_GIVEN,
        status: Literal["active", "inactive"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ListGetResponse:
        """
        This endpoint allows you to **query all the supported coins on CoinGecko with
        coins ID, name and symbol**

        Args:
          include_platform: include platform and token's contract addresses, default: false

          status: filter by status of coins, default: active

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/coins/list",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "include_platform": include_platform,
                        "status": status,
                    },
                    list_get_params.ListGetParams,
                ),
            ),
            cast_to=ListGetResponse,
        )

    def get_new(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ListGetNewResponse:
        """
        This endpoint allows you to **query the latest 200 coins that recently listed on
        CoinGecko**
        """
        return self._get(
            "/coins/list/new",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ListGetNewResponse,
        )


class AsyncListResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncListResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncListResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncListResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncListResourceWithStreamingResponse(self)

    async def get(
        self,
        *,
        include_platform: bool | NotGiven = NOT_GIVEN,
        status: Literal["active", "inactive"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ListGetResponse:
        """
        This endpoint allows you to **query all the supported coins on CoinGecko with
        coins ID, name and symbol**

        Args:
          include_platform: include platform and token's contract addresses, default: false

          status: filter by status of coins, default: active

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/coins/list",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "include_platform": include_platform,
                        "status": status,
                    },
                    list_get_params.ListGetParams,
                ),
            ),
            cast_to=ListGetResponse,
        )

    async def get_new(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ListGetNewResponse:
        """
        This endpoint allows you to **query the latest 200 coins that recently listed on
        CoinGecko**
        """
        return await self._get(
            "/coins/list/new",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ListGetNewResponse,
        )


class ListResourceWithRawResponse:
    def __init__(self, list: ListResource) -> None:
        self._list = list

        self.get = to_raw_response_wrapper(
            list.get,
        )
        self.get_new = to_raw_response_wrapper(
            list.get_new,
        )


class AsyncListResourceWithRawResponse:
    def __init__(self, list: AsyncListResource) -> None:
        self._list = list

        self.get = async_to_raw_response_wrapper(
            list.get,
        )
        self.get_new = async_to_raw_response_wrapper(
            list.get_new,
        )


class ListResourceWithStreamingResponse:
    def __init__(self, list: ListResource) -> None:
        self._list = list

        self.get = to_streamed_response_wrapper(
            list.get,
        )
        self.get_new = to_streamed_response_wrapper(
            list.get_new,
        )


class AsyncListResourceWithStreamingResponse:
    def __init__(self, list: AsyncListResource) -> None:
        self._list = list

        self.get = async_to_streamed_response_wrapper(
            list.get,
        )
        self.get_new = async_to_streamed_response_wrapper(
            list.get_new,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["TrendingPoolGetParams"]


class TrendingPoolGetParams(TypedDict, total=False):
    duration: Literal["5m", "1h", "6h", "24h"]
    """duration to sort trending list by Default value: 24h"""

    include: str
    """
    attributes to include, comma-separated if more than one to include Available
    values: `base_token`, `quote_token`, `dex`, `network`. Example: `base_token` or
    `base_token,dex`
    """

    page: int
    """page through results Default value: 1"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["ExchangeGetResponse"]


class ExchangeGetResponse(BaseModel):
    id: Optional[str] = None
    """exchange ID"""

    country: Optional[str] = None
    """exchange country"""

    description: Optional[str] = None
    """exchange description"""

    has_trading_incentive: Optional[bool] = None
    """exchange trading incentive"""

    image: Optional[str] = None
    """exchange image url"""

    name: Optional[str] = None
    """exchange name"""

    trade_volume_24h_btc: Optional[float] = None
    """exchange trade volume in BTC in 24 hours"""

    trust_score: Optional[float] = None
    """exchange trust score"""

    trust_score_rank: Optional[float] = None
    """exchange trust score rank"""

    url: Optional[str] = None
    """exchange website url"""

    year_established: Optional[float] = None
    """exchange established year"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.global_ import market_cap_chart_get_params
from ...types.global_.market_cap_chart_get_response import MarketCapChartGetResponse

__all__ = ["MarketCapChartResource", "AsyncMarketCapChartResource"]


class MarketCapChartResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> MarketCapChartResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return MarketCapChartResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MarketCapChartResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return MarketCapChartResourceWithStreamingResponse(self)

    def get(
        self,
        *,
        days: Literal["1", "7", "14", "30", "90", "180", "365", "max"],
        vs_currency: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MarketCapChartGetResponse:
        """
        This endpoint allows you to **query historical global market cap and volume data
        by number of days away from now**

        Args:
          days: data up to number of days ago Valid values: any integer

          vs_currency: target currency of market cap, default: usd \\**refers to
              [`/simple/supported_vs_currencies`](/reference/simple-supported-currencies)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/global/market_cap_chart",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "days": days,
                        "vs_currency": vs_currency,
                    },
                    market_cap_chart_get_params.MarketCapChartGetParams,
                ),
            ),
            cast_to=MarketCapChartGetResponse,
        )


class AsyncMarketCapChartResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncMarketCapChartResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncMarketCapChartResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMarketCapChartResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncMarketCapChartResourceWithStreamingResponse(self)

    async def get(
        self,
        *,
        days: Literal["1", "7", "14", "30", "90", "180", "365", "max"],
        vs_currency: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MarketCapChartGetResponse:
        """
        This endpoint allows you to **query historical global market cap and volume data
        by number of days away from now**

        Args:
          days: data up to number of days ago Valid values: any integer

          vs_currency: target currency of market cap, default: usd \\**refers to
              [`/simple/supported_vs_currencies`](/reference/simple-supported-currencies)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/global/market_cap_chart",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "days": days,
                        "vs_currency": vs_currency,
                    },
                    market_cap_chart_get_params.MarketCapChartGetParams,
                ),
            ),
            cast_to=MarketCapChartGetResponse,
        )


class MarketCapChartResourceWithRawResponse:
    def __init__(self, market_cap_chart: MarketCapChartResource) -> None:
        self._market_cap_chart = market_cap_chart

        self.get = to_raw_response_wrapper(
            market_cap_chart.get,
        )


class AsyncMarketCapChartResourceWithRawResponse:
    def __init__(self, market_cap_chart: AsyncMarketCapChartResource) -> None:
        self._market_cap_chart = market_cap_chart

        self.get = async_to_raw_response_wrapper(
            market_cap_chart.get,
        )


class MarketCapChartResourceWithStreamingResponse:
    def __init__(self, market_cap_chart: MarketCapChartResource) -> None:
        self._market_cap_chart = market_cap_chart

        self.get = to_streamed_response_wrapper(
            market_cap_chart.get,
        )


class AsyncMarketCapChartResourceWithStreamingResponse:
    def __init__(self, market_cap_chart: AsyncMarketCapChartResource) -> None:
        self._market_cap_chart = market_cap_chart

        self.get = async_to_streamed_response_wrapper(
            market_cap_chart.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .info import (
    InfoResource,
    AsyncInfoResource,
    InfoResourceWithRawResponse,
    AsyncInfoResourceWithRawResponse,
    InfoResourceWithStreamingResponse,
    AsyncInfoResourceWithStreamingResponse,
)
from .multi import (
    MultiResource,
    AsyncMultiResource,
    MultiResourceWithRawResponse,
    AsyncMultiResourceWithRawResponse,
    MultiResourceWithStreamingResponse,
    AsyncMultiResourceWithStreamingResponse,
)
from .ohlcv import (
    OhlcvResource,
    AsyncOhlcvResource,
    OhlcvResourceWithRawResponse,
    AsyncOhlcvResourceWithRawResponse,
    OhlcvResourceWithStreamingResponse,
    AsyncOhlcvResourceWithStreamingResponse,
)
from .pools import (
    PoolsResource,
    AsyncPoolsResource,
    PoolsResourceWithRawResponse,
    AsyncPoolsResourceWithRawResponse,
    PoolsResourceWithStreamingResponse,
    AsyncPoolsResourceWithStreamingResponse,
)
from .trades import (
    TradesResource,
    AsyncTradesResource,
    TradesResourceWithRawResponse,
    AsyncTradesResourceWithRawResponse,
    TradesResourceWithStreamingResponse,
    AsyncTradesResourceWithStreamingResponse,
)

__all__ = [
    "MultiResource",
    "AsyncMultiResource",
    "MultiResourceWithRawResponse",
    "AsyncMultiResourceWithRawResponse",
    "MultiResourceWithStreamingResponse",
    "AsyncMultiResourceWithStreamingResponse",
    "InfoResource",
    "AsyncInfoResource",
    "InfoResourceWithRawResponse",
    "AsyncInfoResourceWithRawResponse",
    "InfoResourceWithStreamingResponse",
    "AsyncInfoResourceWithStreamingResponse",
    "OhlcvResource",
    "AsyncOhlcvResource",
    "OhlcvResourceWithRawResponse",
    "AsyncOhlcvResourceWithRawResponse",
    "OhlcvResourceWithStreamingResponse",
    "AsyncOhlcvResourceWithStreamingResponse",
    "TradesResource",
    "AsyncTradesResource",
    "TradesResourceWithRawResponse",
    "AsyncTradesResourceWithRawResponse",
    "TradesResourceWithStreamingResponse",
    "AsyncTradesResourceWithStreamingResponse",
    "PoolsResource",
    "AsyncPoolsResource",
    "PoolsResourceWithRawResponse",
    "AsyncPoolsResourceWithRawResponse",
    "PoolsResourceWithStreamingResponse",
    "AsyncPoolsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["ExchangeGetResponse"]


class ExchangeGetResponse(BaseModel):
    id: Optional[str] = None
    """derivatives exchange ID"""

    country: Optional[str] = None
    """derivatives exchange incorporated country"""

    description: Optional[str] = None
    """derivatives exchange description"""

    image: Optional[str] = None
    """derivatives exchange image url"""

    name: Optional[str] = None
    """derivatives exchange name"""

    number_of_futures_pairs: Optional[float] = None
    """number of futures pairs in the derivatives exchange"""

    number_of_perpetual_pairs: Optional[float] = None
    """number of perpetual pairs in the derivatives exchange"""

    open_interest_btc: Optional[float] = None
    """derivatives exchange open interest in BTC"""

    trade_volume_24h_btc: Optional[str] = None
    """derivatives exchange trade volume in BTC in 24 hours"""

    url: Optional[str] = None
    """derivatives exchange website url"""

    year_established: Optional[float] = None
    """derivatives exchange established year"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ...types import nft_get_list_params, nft_get_markets_params
from .tickers import (
    TickersResource,
    AsyncTickersResource,
    TickersResourceWithRawResponse,
    AsyncTickersResourceWithRawResponse,
    TickersResourceWithStreamingResponse,
    AsyncTickersResourceWithStreamingResponse,
)
from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .market_chart import (
    MarketChartResource,
    AsyncMarketChartResource,
    MarketChartResourceWithRawResponse,
    AsyncMarketChartResourceWithRawResponse,
    MarketChartResourceWithStreamingResponse,
    AsyncMarketChartResourceWithStreamingResponse,
)
from ..._base_client import make_request_options
from .contract.contract import (
    ContractResource,
    AsyncContractResource,
    ContractResourceWithRawResponse,
    AsyncContractResourceWithRawResponse,
    ContractResourceWithStreamingResponse,
    AsyncContractResourceWithStreamingResponse,
)
from ...types.nft_get_id_response import NFTGetIDResponse
from ...types.nft_get_list_response import NFTGetListResponse
from ...types.nft_get_markets_response import NFTGetMarketsResponse

__all__ = ["NFTsResource", "AsyncNFTsResource"]


class NFTsResource(SyncAPIResource):
    @cached_property
    def contract(self) -> ContractResource:
        return ContractResource(self._client)

    @cached_property
    def market_chart(self) -> MarketChartResource:
        return MarketChartResource(self._client)

    @cached_property
    def tickers(self) -> TickersResource:
        return TickersResource(self._client)

    @cached_property
    def with_raw_response(self) -> NFTsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return NFTsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> NFTsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return NFTsResourceWithStreamingResponse(self)

    def get_id(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NFTGetIDResponse:
        """
        This endpoint allows you to **query all the NFT data (name, floor price, 24hr
        volume ...) based on the NFT collection ID**

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/nfts/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NFTGetIDResponse,
        )

    def get_list(
        self,
        *,
        order: Literal[
            "h24_volume_usd_asc",
            "h24_volume_usd_desc",
            "h24_volume_native_asc",
            "h24_volume_native_desc",
            "floor_price_native_asc",
            "floor_price_native_desc",
            "market_cap_native_asc",
            "market_cap_native_desc",
            "market_cap_usd_asc",
            "market_cap_usd_desc",
        ]
        | NotGiven = NOT_GIVEN,
        page: float | NotGiven = NOT_GIVEN,
        per_page: float | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NFTGetListResponse:
        """
        This endpoint allows you to **query all supported NFTs with ID, contract
        address, name, asset platform ID and symbol on CoinGecko**

        Args:
          order: use this to sort the order of responses

          page: page through results

          per_page: total results per page Valid values: 1...250

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/nfts/list",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "order": order,
                        "page": page,
                        "per_page": per_page,
                    },
                    nft_get_list_params.NFTGetListParams,
                ),
            ),
            cast_to=NFTGetListResponse,
        )

    def get_markets(
        self,
        *,
        asset_platform_id: str | NotGiven = NOT_GIVEN,
        order: Literal[
            "h24_volume_native_asc",
            "h24_volume_native_desc",
            "h24_volume_usd_asc",
            "h24_volume_usd_desc",
            "market_cap_usd_asc",
            "market_cap_usd_desc",
        ]
        | NotGiven = NOT_GIVEN,
        page: float | NotGiven = NOT_GIVEN,
        per_page: float | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NFTGetMarketsResponse:
        """
        This endpoint allows you to **query all the supported NFT collections with floor
        price, market cap, volume and market related data on CoinGecko**

        Args:
          asset_platform_id: filter result by asset platform (blockchain network) \\**refers to
              [`/asset_platforms`](/reference/asset-platforms-list) filter=`nft`

          order: sort results by field Default: `market_cap_usd_desc`

          page: page through results Default: `1`

          per_page:
              total results per page Valid values: any integer between 1 and 250 Default:
              `100`

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/nfts/markets",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "asset_platform_id": asset_platform_id,
                        "order": order,
                        "page": page,
                        "per_page": per_page,
                    },
                    nft_get_markets_params.NFTGetMarketsParams,
                ),
            ),
            cast_to=NFTGetMarketsResponse,
        )


class AsyncNFTsResource(AsyncAPIResource):
    @cached_property
    def contract(self) -> AsyncContractResource:
        return AsyncContractResource(self._client)

    @cached_property
    def market_chart(self) -> AsyncMarketChartResource:
        return AsyncMarketChartResource(self._client)

    @cached_property
    def tickers(self) -> AsyncTickersResource:
        return AsyncTickersResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncNFTsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncNFTsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncNFTsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncNFTsResourceWithStreamingResponse(self)

    async def get_id(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NFTGetIDResponse:
        """
        This endpoint allows you to **query all the NFT data (name, floor price, 24hr
        volume ...) based on the NFT collection ID**

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/nfts/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NFTGetIDResponse,
        )

    async def get_list(
        self,
        *,
        order: Literal[
            "h24_volume_usd_asc",
            "h24_volume_usd_desc",
            "h24_volume_native_asc",
            "h24_volume_native_desc",
            "floor_price_native_asc",
            "floor_price_native_desc",
            "market_cap_native_asc",
            "market_cap_native_desc",
            "market_cap_usd_asc",
            "market_cap_usd_desc",
        ]
        | NotGiven = NOT_GIVEN,
        page: float | NotGiven = NOT_GIVEN,
        per_page: float | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NFTGetListResponse:
        """
        This endpoint allows you to **query all supported NFTs with ID, contract
        address, name, asset platform ID and symbol on CoinGecko**

        Args:
          order: use this to sort the order of responses

          page: page through results

          per_page: total results per page Valid values: 1...250

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/nfts/list",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "order": order,
                        "page": page,
                        "per_page": per_page,
                    },
                    nft_get_list_params.NFTGetListParams,
                ),
            ),
            cast_to=NFTGetListResponse,
        )

    async def get_markets(
        self,
        *,
        asset_platform_id: str | NotGiven = NOT_GIVEN,
        order: Literal[
            "h24_volume_native_asc",
            "h24_volume_native_desc",
            "h24_volume_usd_asc",
            "h24_volume_usd_desc",
            "market_cap_usd_asc",
            "market_cap_usd_desc",
        ]
        | NotGiven = NOT_GIVEN,
        page: float | NotGiven = NOT_GIVEN,
        per_page: float | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NFTGetMarketsResponse:
        """
        This endpoint allows you to **query all the supported NFT collections with floor
        price, market cap, volume and market related data on CoinGecko**

        Args:
          asset_platform_id: filter result by asset platform (blockchain network) \\**refers to
              [`/asset_platforms`](/reference/asset-platforms-list) filter=`nft`

          order: sort results by field Default: `market_cap_usd_desc`

          page: page through results Default: `1`

          per_page:
              total results per page Valid values: any integer between 1 and 250 Default:
              `100`

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/nfts/markets",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "asset_platform_id": asset_platform_id,
                        "order": order,
                        "page": page,
                        "per_page": per_page,
                    },
                    nft_get_markets_params.NFTGetMarketsParams,
                ),
            ),
            cast_to=NFTGetMarketsResponse,
        )


class NFTsResourceWithRawResponse:
    def __init__(self, nfts: NFTsResource) -> None:
        self._nfts = nfts

        self.get_id = to_raw_response_wrapper(
            nfts.get_id,
        )
        self.get_list = to_raw_response_wrapper(
            nfts.get_list,
        )
        self.get_markets = to_raw_response_wrapper(
            nfts.get_markets,
        )

    @cached_property
    def contract(self) -> ContractResourceWithRawResponse:
        return ContractResourceWithRawResponse(self._nfts.contract)

    @cached_property
    def market_chart(self) -> MarketChartResourceWithRawResponse:
        return MarketChartResourceWithRawResponse(self._nfts.market_chart)

    @cached_property
    def tickers(self) -> TickersResourceWithRawResponse:
        return TickersResourceWithRawResponse(self._nfts.tickers)


class AsyncNFTsResourceWithRawResponse:
    def __init__(self, nfts: AsyncNFTsResource) -> None:
        self._nfts = nfts

        self.get_id = async_to_raw_response_wrapper(
            nfts.get_id,
        )
        self.get_list = async_to_raw_response_wrapper(
            nfts.get_list,
        )
        self.get_markets = async_to_raw_response_wrapper(
            nfts.get_markets,
        )

    @cached_property
    def contract(self) -> AsyncContractResourceWithRawResponse:
        return AsyncContractResourceWithRawResponse(self._nfts.contract)

    @cached_property
    def market_chart(self) -> AsyncMarketChartResourceWithRawResponse:
        return AsyncMarketChartResourceWithRawResponse(self._nfts.market_chart)

    @cached_property
    def tickers(self) -> AsyncTickersResourceWithRawResponse:
        return AsyncTickersResourceWithRawResponse(self._nfts.tickers)


class NFTsResourceWithStreamingResponse:
    def __init__(self, nfts: NFTsResource) -> None:
        self._nfts = nfts

        self.get_id = to_streamed_response_wrapper(
            nfts.get_id,
        )
        self.get_list = to_streamed_response_wrapper(
            nfts.get_list,
        )
        self.get_markets = to_streamed_response_wrapper(
            nfts.get_markets,
        )

    @cached_property
    def contract(self) -> ContractResourceWithStreamingResponse:
        return ContractResourceWithStreamingResponse(self._nfts.contract)

    @cached_property
    def market_chart(self) -> MarketChartResourceWithStreamingResponse:
        return MarketChartResourceWithStreamingResponse(self._nfts.market_chart)

    @cached_property
    def tickers(self) -> TickersResourceWithStreamingResponse:
        return TickersResourceWithStreamingResponse(self._nfts.tickers)


class AsyncNFTsResourceWithStreamingResponse:
    def __init__(self, nfts: AsyncNFTsResource) -> None:
        self._nfts = nfts

        self.get_id = async_to_streamed_response_wrapper(
            nfts.get_id,
        )
        self.get_list = async_to_streamed_response_wrapper(
            nfts.get_list,
        )
        self.get_markets = async_to_streamed_response_wrapper(
            nfts.get_markets,
        )

    @cached_property
    def contract(self) -> AsyncContractResourceWithStreamingResponse:
        return AsyncContractResourceWithStreamingResponse(self._nfts.contract)

    @cached_property
    def market_chart(self) -> AsyncMarketChartResourceWithStreamingResponse:
        return AsyncMarketChartResourceWithStreamingResponse(self._nfts.market_chart)

    @cached_property
    def tickers(self) -> AsyncTickersResourceWithStreamingResponse:
        return AsyncTickersResourceWithStreamingResponse(self._nfts.tickers)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .networks import (
    NetworksResource,
    AsyncNetworksResource,
    NetworksResourceWithRawResponse,
    AsyncNetworksResourceWithRawResponse,
    NetworksResourceWithStreamingResponse,
    AsyncNetworksResourceWithStreamingResponse,
)
from .token_price import (
    TokenPriceResource,
    AsyncTokenPriceResource,
    TokenPriceResourceWithRawResponse,
    AsyncTokenPriceResourceWithRawResponse,
    TokenPriceResourceWithStreamingResponse,
    AsyncTokenPriceResourceWithStreamingResponse,
)

__all__ = [
    "TokenPriceResource",
    "AsyncTokenPriceResource",
    "TokenPriceResourceWithRawResponse",
    "AsyncTokenPriceResourceWithRawResponse",
    "TokenPriceResourceWithStreamingResponse",
    "AsyncTokenPriceResourceWithStreamingResponse",
    "NetworksResource",
    "AsyncNetworksResource",
    "NetworksResourceWithRawResponse",
    "AsyncNetworksResourceWithRawResponse",
    "NetworksResourceWithStreamingResponse",
    "AsyncNetworksResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from .info import (
    InfoResource,
    AsyncInfoResource,
    InfoResourceWithRawResponse,
    AsyncInfoResourceWithRawResponse,
    InfoResourceWithStreamingResponse,
    AsyncInfoResourceWithStreamingResponse,
)
from .multi import (
    MultiResource,
    AsyncMultiResource,
    MultiResourceWithRawResponse,
    AsyncMultiResourceWithRawResponse,
    MultiResourceWithStreamingResponse,
    AsyncMultiResourceWithStreamingResponse,
)
from .ohlcv import (
    OhlcvResource,
    AsyncOhlcvResource,
    OhlcvResourceWithRawResponse,
    AsyncOhlcvResourceWithRawResponse,
    OhlcvResourceWithStreamingResponse,
    AsyncOhlcvResourceWithStreamingResponse,
)
from .trades import (
    TradesResource,
    AsyncTradesResource,
    TradesResourceWithRawResponse,
    AsyncTradesResourceWithRawResponse,
    TradesResourceWithStreamingResponse,
    AsyncTradesResourceWithStreamingResponse,
)
from ....._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ....._utils import maybe_transform, async_maybe_transform
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....._base_client import make_request_options
from .....types.onchain.networks import pool_get_params, pool_get_address_params
from .....types.onchain.networks.pool_get_response import PoolGetResponse
from .....types.onchain.networks.pool_get_address_response import PoolGetAddressResponse

__all__ = ["PoolsResource", "AsyncPoolsResource"]


class PoolsResource(SyncAPIResource):
    @cached_property
    def multi(self) -> MultiResource:
        return MultiResource(self._client)

    @cached_property
    def info(self) -> InfoResource:
        return InfoResource(self._client)

    @cached_property
    def ohlcv(self) -> OhlcvResource:
        return OhlcvResource(self._client)

    @cached_property
    def trades(self) -> TradesResource:
        return TradesResource(self._client)

    @cached_property
    def with_raw_response(self) -> PoolsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return PoolsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PoolsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return PoolsResourceWithStreamingResponse(self)

    def get(
        self,
        network: str,
        *,
        include: str | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        sort: Literal["h24_tx_count_desc", "h24_volume_usd_desc"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PoolGetResponse:
        """
        This endpoint allows you to **query all the top pools based on the provided
        network**

        Args:
          include: attributes to include, comma-separated if more than one to include Available
              values: `base_token`, `quote_token`, `dex`

          page: page through results Default value: 1

          sort: sort the pools by field Default value: h24_tx_count_desc

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not network:
            raise ValueError(f"Expected a non-empty value for `network` but received {network!r}")
        return self._get(
            f"/onchain/networks/{network}/pools",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "include": include,
                        "page": page,
                        "sort": sort,
                    },
                    pool_get_params.PoolGetParams,
                ),
            ),
            cast_to=PoolGetResponse,
        )

    def get_address(
        self,
        address: str,
        *,
        network: str,
        include: str | NotGiven = NOT_GIVEN,
        include_volume_breakdown: bool | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PoolGetAddressResponse:
        """
        This endpoint allows you to **query the specific pool based on the provided
        network and pool address**

        Args:
          include: attributes to include, comma-separated if more than one to include Available
              values: `base_token`, `quote_token`, `dex`

          include_volume_breakdown: include volume breakdown, default: false

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not network:
            raise ValueError(f"Expected a non-empty value for `network` but received {network!r}")
        if not address:
            raise ValueError(f"Expected a non-empty value for `address` but received {address!r}")
        return self._get(
            f"/onchain/networks/{network}/pools/{address}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "include": include,
                        "include_volume_breakdown": include_volume_breakdown,
                    },
                    pool_get_address_params.PoolGetAddressParams,
                ),
            ),
            cast_to=PoolGetAddressResponse,
        )


class AsyncPoolsResource(AsyncAPIResource):
    @cached_property
    def multi(self) -> AsyncMultiResource:
        return AsyncMultiResource(self._client)

    @cached_property
    def info(self) -> AsyncInfoResource:
        return AsyncInfoResource(self._client)

    @cached_property
    def ohlcv(self) -> AsyncOhlcvResource:
        return AsyncOhlcvResource(self._client)

    @cached_property
    def trades(self) -> AsyncTradesResource:
        return AsyncTradesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncPoolsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPoolsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPoolsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncPoolsResourceWithStreamingResponse(self)

    async def get(
        self,
        network: str,
        *,
        include: str | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        sort: Literal["h24_tx_count_desc", "h24_volume_usd_desc"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PoolGetResponse:
        """
        This endpoint allows you to **query all the top pools based on the provided
        network**

        Args:
          include: attributes to include, comma-separated if more than one to include Available
              values: `base_token`, `quote_token`, `dex`

          page: page through results Default value: 1

          sort: sort the pools by field Default value: h24_tx_count_desc

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not network:
            raise ValueError(f"Expected a non-empty value for `network` but received {network!r}")
        return await self._get(
            f"/onchain/networks/{network}/pools",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "include": include,
                        "page": page,
                        "sort": sort,
                    },
                    pool_get_params.PoolGetParams,
                ),
            ),
            cast_to=PoolGetResponse,
        )

    async def get_address(
        self,
        address: str,
        *,
        network: str,
        include: str | NotGiven = NOT_GIVEN,
        include_volume_breakdown: bool | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PoolGetAddressResponse:
        """
        This endpoint allows you to **query the specific pool based on the provided
        network and pool address**

        Args:
          include: attributes to include, comma-separated if more than one to include Available
              values: `base_token`, `quote_token`, `dex`

          include_volume_breakdown: include volume breakdown, default: false

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not network:
            raise ValueError(f"Expected a non-empty value for `network` but received {network!r}")
        if not address:
            raise ValueError(f"Expected a non-empty value for `address` but received {address!r}")
        return await self._get(
            f"/onchain/networks/{network}/pools/{address}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "include": include,
                        "include_volume_breakdown": include_volume_breakdown,
                    },
                    pool_get_address_params.PoolGetAddressParams,
                ),
            ),
            cast_to=PoolGetAddressResponse,
        )


class PoolsResourceWithRawResponse:
    def __init__(self, pools: PoolsResource) -> None:
        self._pools = pools

        self.get = to_raw_response_wrapper(
            pools.get,
        )
        self.get_address = to_raw_response_wrapper(
            pools.get_address,
        )

    @cached_property
    def multi(self) -> MultiResourceWithRawResponse:
        return MultiResourceWithRawResponse(self._pools.multi)

    @cached_property
    def info(self) -> InfoResourceWithRawResponse:
        return InfoResourceWithRawResponse(self._pools.info)

    @cached_property
    def ohlcv(self) -> OhlcvResourceWithRawResponse:
        return OhlcvResourceWithRawResponse(self._pools.ohlcv)

    @cached_property
    def trades(self) -> TradesResourceWithRawResponse:
        return TradesResourceWithRawResponse(self._pools.trades)


class AsyncPoolsResourceWithRawResponse:
    def __init__(self, pools: AsyncPoolsResource) -> None:
        self._pools = pools

        self.get = async_to_raw_response_wrapper(
            pools.get,
        )
        self.get_address = async_to_raw_response_wrapper(
            pools.get_address,
        )

    @cached_property
    def multi(self) -> AsyncMultiResourceWithRawResponse:
        return AsyncMultiResourceWithRawResponse(self._pools.multi)

    @cached_property
    def info(self) -> AsyncInfoResourceWithRawResponse:
        return AsyncInfoResourceWithRawResponse(self._pools.info)

    @cached_property
    def ohlcv(self) -> AsyncOhlcvResourceWithRawResponse:
        return AsyncOhlcvResourceWithRawResponse(self._pools.ohlcv)

    @cached_property
    def trades(self) -> AsyncTradesResourceWithRawResponse:
        return AsyncTradesResourceWithRawResponse(self._pools.trades)


class PoolsResourceWithStreamingResponse:
    def __init__(self, pools: PoolsResource) -> None:
        self._pools = pools

        self.get = to_streamed_response_wrapper(
            pools.get,
        )
        self.get_address = to_streamed_response_wrapper(
            pools.get_address,
        )

    @cached_property
    def multi(self) -> MultiResourceWithStreamingResponse:
        return MultiResourceWithStreamingResponse(self._pools.multi)

    @cached_property
    def info(self) -> InfoResourceWithStreamingResponse:
        return InfoResourceWithStreamingResponse(self._pools.info)

    @cached_property
    def ohlcv(self) -> OhlcvResourceWithStreamingResponse:
        return OhlcvResourceWithStreamingResponse(self._pools.ohlcv)

    @cached_property
    def trades(self) -> TradesResourceWithStreamingResponse:
        return TradesResourceWithStreamingResponse(self._pools.trades)


class AsyncPoolsResourceWithStreamingResponse:
    def __init__(self, pools: AsyncPoolsResource) -> None:
        self._pools = pools

        self.get = async_to_streamed_response_wrapper(
            pools.get,
        )
        self.get_address = async_to_streamed_response_wrapper(
            pools.get_address,
        )

    @cached_property
    def multi(self) -> AsyncMultiResourceWithStreamingResponse:
        return AsyncMultiResourceWithStreamingResponse(self._pools.multi)

    @cached_property
    def info(self) -> AsyncInfoResourceWithStreamingResponse:
        return AsyncInfoResourceWithStreamingResponse(self._pools.info)

    @cached_property
    def ohlcv(self) -> AsyncOhlcvResourceWithStreamingResponse:
        return AsyncOhlcvResourceWithStreamingResponse(self._pools.ohlcv)

    @cached_property
    def trades(self) -> AsyncTradesResourceWithStreamingResponse:
        return AsyncTradesResourceWithStreamingResponse(self._pools.trades)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ...._models import BaseModel

__all__ = [
    "TrendingPoolGetResponse",
    "Data",
    "DataAttributes",
    "DataAttributesPriceChangePercentage",
    "DataAttributesTransactions",
    "DataAttributesTransactionsH1",
    "DataAttributesTransactionsH24",
    "DataAttributesTransactionsM15",
    "DataAttributesTransactionsM30",
    "DataAttributesTransactionsM5",
    "DataAttributesVolumeUsd",
    "DataRelationships",
    "DataRelationshipsBaseToken",
    "DataRelationshipsBaseTokenData",
    "DataRelationshipsDex",
    "DataRelationshipsDexData",
    "DataRelationshipsQuoteToken",
    "DataRelationshipsQuoteTokenData",
    "Included",
    "IncludedAttributes",
]


class DataAttributesPriceChangePercentage(BaseModel):
    h1: Optional[str] = None

    h24: Optional[str] = None

    h6: Optional[str] = None

    m15: Optional[str] = None

    m30: Optional[str] = None

    m5: Optional[str] = None


class DataAttributesTransactionsH1(BaseModel):
    buyers: Optional[int] = None

    buys: Optional[int] = None

    sellers: Optional[int] = None

    sells: Optional[int] = None


class DataAttributesTransactionsH24(BaseModel):
    buyers: Optional[int] = None

    buys: Optional[int] = None

    sellers: Optional[int] = None

    sells: Optional[int] = None


class DataAttributesTransactionsM15(BaseModel):
    buyers: Optional[int] = None

    buys: Optional[int] = None

    sellers: Optional[int] = None

    sells: Optional[int] = None


class DataAttributesTransactionsM30(BaseModel):
    buyers: Optional[int] = None

    buys: Optional[int] = None

    sellers: Optional[int] = None

    sells: Optional[int] = None


class DataAttributesTransactionsM5(BaseModel):
    buyers: Optional[int] = None

    buys: Optional[int] = None

    sellers: Optional[int] = None

    sells: Optional[int] = None


class DataAttributesTransactions(BaseModel):
    h1: Optional[DataAttributesTransactionsH1] = None

    h24: Optional[DataAttributesTransactionsH24] = None

    m15: Optional[DataAttributesTransactionsM15] = None

    m30: Optional[DataAttributesTransactionsM30] = None

    m5: Optional[DataAttributesTransactionsM5] = None


class DataAttributesVolumeUsd(BaseModel):
    h1: Optional[str] = None

    h24: Optional[str] = None

    h6: Optional[str] = None

    m15: Optional[str] = None

    m30: Optional[str] = None

    m5: Optional[str] = None


class DataAttributes(BaseModel):
    address: Optional[str] = None

    base_token_price_native_currency: Optional[str] = None

    base_token_price_quote_token: Optional[str] = None

    base_token_price_usd: Optional[str] = None

    fdv_usd: Optional[str] = None

    market_cap_usd: Optional[str] = None

    name: Optional[str] = None

    pool_created_at: Optional[str] = None

    price_change_percentage: Optional[DataAttributesPriceChangePercentage] = None

    quote_token_price_base_token: Optional[str] = None

    quote_token_price_native_currency: Optional[str] = None

    quote_token_price_usd: Optional[str] = None

    reserve_in_usd: Optional[str] = None

    transactions: Optional[DataAttributesTransactions] = None

    volume_usd: Optional[DataAttributesVolumeUsd] = None


class DataRelationshipsBaseTokenData(BaseModel):
    id: Optional[str] = None

    type: Optional[str] = None


class DataRelationshipsBaseToken(BaseModel):
    data: Optional[DataRelationshipsBaseTokenData] = None


class DataRelationshipsDexData(BaseModel):
    id: Optional[str] = None

    type: Optional[str] = None


class DataRelationshipsDex(BaseModel):
    data: Optional[DataRelationshipsDexData] = None


class DataRelationshipsQuoteTokenData(BaseModel):
    id: Optional[str] = None

    type: Optional[str] = None


class DataRelationshipsQuoteToken(BaseModel):
    data: Optional[DataRelationshipsQuoteTokenData] = None


class DataRelationships(BaseModel):
    base_token: Optional[DataRelationshipsBaseToken] = None

    dex: Optional[DataRelationshipsDex] = None

    quote_token: Optional[DataRelationshipsQuoteToken] = None


class Data(BaseModel):
    id: Optional[str] = None

    attributes: Optional[DataAttributes] = None

    relationships: Optional[DataRelationships] = None

    type: Optional[str] = None


class IncludedAttributes(BaseModel):
    address: Optional[str] = None

    coingecko_coin_id: Optional[str] = None

    decimals: Optional[int] = None

    image_url: Optional[str] = None

    name: Optional[str] = None

    symbol: Optional[str] = None


class Included(BaseModel):
    id: Optional[str] = None

    attributes: Optional[IncludedAttributes] = None

    type: Optional[str] = None


class TrendingPoolGetResponse(BaseModel):
    data: Optional[List[Data]] = None

    included: Optional[List[Included]] = None
